yakumo.neutron.v2.router

Package yakumo :: Package neutron :: Package v2 :: Module router |
[hide private]
[frames] | no frames]

# Module router

source code

Resource class and its manager for routers in Networking V2 API

Classes | [hide private]
| Resource Resource class for routers in Networking V2 API
| Manager Manager class for routers in Networking V2 API

Variables | [hide private]
| FIXED_IP_MAPPING = ``[``(``'``ip_address``'``,` `'``ip_address``'``,` <yakumo.mappe`...``
| EXTERNAL_GATEWAY_INFO_MAPPING = ``[``(``'``network``'``,` `'``network_id``'``,` <ya`...``
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2``'``

Variables Details | [hide private]

  ### FIXED_IP_MAPPING Value:
      [('ip_address', 'ip_address', mapper.Noop), ('subnet', 'subnet_id', ma
      pper.Resource('subnet'))]

  ### EXTERNAL_GATEWAY_INFO_MAPPING Value:
      [('network',
        'network_id',
        <yakumo.mapper.Resource object at 0x7f1333c44e90>),
       ('is_snat_enabled',
        'enable_snat',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('external_fixed_ips',
        'external_fixed_ips',
      ...

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('status',
      'status', mapper.Noop), ('routes', 'routes', mapper.Noop), ('project',
       'tenant_id', mapper.Resource('project')), ('is_enabled', 'admin_state
      _up', mapper.Noop), ('external_gateway_info', 'external_gateway_info',
       mapper.Dict(EXTERNAL_GATEWAY_INFO_MAPPING)), ('is_distributed', 'dist
      ributed', mapper.Noop), ('is_ha', 'ha', mapper.Noop),]